@@ -13,6 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -23,6 +24,9 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check if cloud services are disabled
+    $Self->{CloudServicesDisabled} = $Kernel::OM->Get('Kernel::Config')->Get('CloudServices::Disabled') || 0;
+
     return $Self;
 }
 
@@ -53,12 +57,9 @@ sub Run {
                 }
                 if ( !$ApacheReload ) {
                     return $LayoutObject->ErrorScreen(
-                        Message =>
-                            'Sorry, Apache::Reload is needed as PerlModule and '
-                            .
-                            'PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf. '
-                            .
-                            'Alternatively, you can use the commandline tool bin/otrs.Console.pl to install packages!'
+                        Message => Translatable(
+                            'Sorry, Apache::Reload is needed as PerlModule and PerlInitHandler in Apache config file. See also scripts/apache2-httpd.include.conf. Alternatively, you can use the command line tool bin/otrs.Console.pl to install packages!'
+                        ),
                     );
                 }
             }
@@ -91,7 +92,9 @@ sub Run {
             Result  => 'SCALAR',
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
         my %Structure = $PackageObject->PackageParse( String => $Package );
         my $File = '';
@@ -113,7 +116,7 @@ sub Run {
                     Location => $Location,
                     Name     => $Name,
                     Version  => $Version,
-                    Diff     => "No such file $LocalFile in package!",
+                    Diff     => $LayoutObject->{LanguageObject}->Translate( 'No such file %s in package!', $LocalFile ),
                 },
             );
         }
@@ -124,7 +127,8 @@ sub Run {
                     Location => $Location,
                     Name     => $Name,
                     Version  => $Version,
-                    Diff     => "No such file $LocalFile in local file system!",
+                    Diff     => $LayoutObject->{LanguageObject}
+                        ->Translate( 'No such file %s in local file system!', $LocalFile ),
                 },
             );
         }
@@ -153,7 +157,7 @@ sub Run {
                         Location => $Location,
                         Name     => $Name,
                         Version  => $Version,
-                        Diff     => "Can't read $LocalFile!",
+                        Diff     => $LayoutObject->{LanguageObject}->Translate( 'Can\'t read %s!', $LocalFile ),
                     },
                 );
             }
@@ -185,7 +189,9 @@ sub Run {
             Result  => 'SCALAR',
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         # parse package
@@ -231,7 +237,9 @@ sub Run {
             && !$Structure{PackageIsVisible}->{Content}
             )
         {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         PACKAGEACTION:
@@ -780,7 +788,9 @@ sub Run {
             Version => $Version,
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
         return $LayoutObject->Attachment(
             Content     => $Package,
@@ -804,7 +814,9 @@ sub Run {
 
         # check
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
         return $LayoutObject->Attachment(
             Content     => $Package,
@@ -918,7 +930,9 @@ sub Run {
             Result  => 'SCALAR',
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         # check if we have to show reinstall intro pre
@@ -998,7 +1012,9 @@ sub Run {
             Version => $Version,
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         # check if we have to show reinstall intro pre
@@ -1062,7 +1078,9 @@ sub Run {
             Result  => 'SCALAR',
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         # check if we have to show uninstall intro pre
@@ -1141,7 +1159,9 @@ sub Run {
             Version => $Version,
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
 
         # parse package
@@ -1263,7 +1283,9 @@ sub Run {
             Result  => 'SCALAR',
         );
         if ( !$Package ) {
-            return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('No such package!'),
+            );
         }
         my %Structure = $PackageObject->PackageParse(
             String => $Package,
@@ -1297,7 +1319,7 @@ sub Run {
     my $RegistrationState = $Kernel::OM->Get('Kernel::System::SystemData')->SystemDataGet(
         Key => 'Registration::State',
     ) || '';
-    if ( $RegistrationState eq 'registered' ) {
+    if ( $RegistrationState eq 'registered' && !$Self->{CloudServicesDisabled} ) {
 
         $RepositoryCloudList =
             $PackageObject->RepositoryCloudList( NoCache => 1 );
@@ -1335,7 +1357,7 @@ sub Run {
             if ( !$OutputNotify ) {
                 $OutputNotify .= $LayoutObject->Notify(
                     Priority => 'Info',
-                    Info     => 'No packages, or no new packages, found in selected repository.',
+                    Info     => Translatable('No packages or no new packages found in selected repository.'),
                 );
             }
             $LayoutObject->Block(
@@ -1444,6 +1466,7 @@ sub Run {
         if (
             $VerificationData{ $Package->{Name}->{Content} }
             && $VerificationData{ $Package->{Name}->{Content} } eq 'verified'
+            && !$Self->{CloudServicesDisabled}
             )
         {
             $LayoutObject->Block(
@@ -1578,7 +1601,11 @@ sub Run {
 
     # FeatureAddons
     if ( $ConfigObject->Get('Package::ShowFeatureAddons') ) {
-        my $FeatureAddonData = $Self->_GetFeatureAddonData();
+
+        my $FeatureAddonData;
+        if ( !$Self->{CloudServicesDisabled} ) {
+            $FeatureAddonData = $Self->_GetFeatureAddonData();
+        }
 
         if ( ref $FeatureAddonData eq 'ARRAY' && scalar @{$FeatureAddonData} > 0 ) {
             $LayoutObject->Block(
@@ -1594,6 +1621,12 @@ sub Run {
         }
     }
 
+    if ( $Self->{CloudServicesDisabled} ) {
+        $LayoutObject->Block(
+            Name => 'CloudServicesWarning',
+        );
+    }
+
     my $Output = $LayoutObject->Header();
     $Output .= $LayoutObject->NavigationBar();
     $Output .= $OutputNotify;
@@ -1633,19 +1666,22 @@ sub Run {
         );
     }
 
-    VERIFICATION:
-    for my $Package ( sort keys %UnknownVerficationPackages ) {
+    if ( !$Self->{CloudServicesDisabled} ) {
 
-        next VERIFICATION if !$Package;
-        next VERIFICATION if !$UnknownVerficationPackages{$Package};
+        VERIFICATION:
+        for my $Package ( sort keys %UnknownVerficationPackages ) {
 
-        $Output .= $LayoutObject->Notify(
-            Priority => 'Error',
-            Data     => "$Package $UnknownVerficationPackages{$Package} - "
-                . $LayoutObject->{LanguageObject}->Translate(
-                "Package not verified due a communication issue with verification server!"
-                ),
-        );
+            next VERIFICATION if !$Package;
+            next VERIFICATION if !$UnknownVerficationPackages{$Package};
+
+            $Output .= $LayoutObject->Notify(
+                Priority => 'Error',
+                Data     => "$Package $UnknownVerficationPackages{$Package} - "
+                    . $LayoutObject->{LanguageObject}->Translate(
+                    "Package not verified due a communication issue with verification server!"
+                    ),
+            );
+        }
     }
 
     $Output .= $LayoutObject->Output(
@@ -1777,7 +1813,9 @@ sub _InstallHandling {
 
     # check needed params
     if ( !$Param{Package} ) {
-        return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('No such package!'),
+        );
     }
 
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
@@ -1847,11 +1885,13 @@ sub _InstallHandling {
     }
 
     # get cloud repositories
-    my $RepositoryCloudList =
-        $PackageObject->RepositoryCloudList();
+    my $RepositoryCloudList;
+    if ( !$Self->{CloudServicesDisabled} ) {
+        $RepositoryCloudList = $PackageObject->RepositoryCloudList();
+    }
 
     # in case Source is present on repository cloud list
-    # the package shold be retrieved using the CloudService backend
+    # the package should be retrieved using the CloudService backend
     my $FromCloud = 0;
     if ( $Param{Source} && $RepositoryCloudList->{ $Param{Source} } ) {
         $FromCloud = 1;
@@ -1872,7 +1912,7 @@ sub _InstallHandling {
             },
         );
 
-        if ( $Verified eq 'verified' ) {
+        if ( $Verified eq 'verified' && !$Self->{CloudServicesDisabled} ) {
             $LayoutObject->Block(
                 Name => 'OTRSVerifyLogo',
             );
@@ -1949,7 +1989,9 @@ sub _UpgradeHandling {
 
     # check needed params
     if ( !$Param{Package} ) {
-        return $LayoutObject->ErrorScreen( Message => 'No such package!' );
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('No such package!'),
+        );
     }
 
     my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
@@ -2084,7 +2126,7 @@ sub _GetFeatureAddonData {
     # as this is the only operation an unsuccessful request means that the operation was also
     # unsuccessful
     if ( !IsHashRefWithData($RequestResult) ) {
-        return "Can't connect to OTRS Feature Add-on list server!";
+        return Translatable('Can\'t connect to OTRS Feature Add-on list server!');
     }
 
     my $OperationResult = $CloudServiceObject->OperationResultGet(
@@ -2094,10 +2136,10 @@ sub _GetFeatureAddonData {
     );
 
     if ( !IsHashRefWithData($OperationResult) ) {
-        return "Can't get OTRS Feature Add-on list from server";
+        return Translatable('Can\'t get OTRS Feature Add-on list from server!');
     }
     elsif ( !$OperationResult->{Success} ) {
-        return $OperationResult->{ErrorMessage} || "Can't get OTRS Feature Add-on from server!";
+        return $OperationResult->{ErrorMessage} || Translatable('Can\'t get OTRS Feature Add-on from server!');
     }
 
     my $FAOFeed = $OperationResult->{Data}->{FAOs};
