@@ -14,6 +14,7 @@ use warnings;
 use Data::Dumper;
 
 use Kernel::System::VariableCheck qw(:all);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -44,8 +45,9 @@ sub Run {
         UserID => $Self->{UserID}
     );
 
-    my $SynchronizeMessage
-        = 'Process Management information from database is not in sync with the system configuration, please synchronize all processes.';
+    my $SynchronizeMessage = Translatable(
+        'Process Management information from database is not in sync with the system configuration, please synchronize all processes.'
+    );
 
     if ( IsArrayRefWithData($EntitySyncStateList) ) {
 
@@ -79,7 +81,7 @@ sub Run {
 
             if ( !$ExampleProcessFilename ) {
                 return $Kernel::OM->Get('Kernel::Output::HTML::Layout')->FatalError(
-                    Message => "Need ExampleProcesses!",
+                    Message => Translatable('Need ExampleProcesses!'),
                 );
             }
 
@@ -91,7 +93,8 @@ sub Run {
 
             if ( !$Content ) {
                 return $Kernel::OM->Get('Kernel::Output::HTML::Layout')->FatalError(
-                    Message => "Could not read $ExampleProcessFilename!",
+                    Message =>
+                        $LayoutObject->{LanguageObject}->Translate( 'Could not read %s!', $ExampleProcessFilename ),
                 );
             }
 
@@ -149,7 +152,7 @@ sub Run {
         my $ProcessID = $ParamObject->GetParam( Param => 'ID' ) || '';
         if ( !$ProcessID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need ProcessID!",
+                Message => Translatable('Need ProcessID!'),
             );
         }
 
@@ -183,14 +186,14 @@ sub Run {
         my $ProcessID = $ParamObject->GetParam( Param => 'ID' ) || '';
         if ( !$ProcessID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need ProcessID!",
+                Message => Translatable('Need ProcessID!'),
             );
         }
 
         my $BooleanMapping = {
-            0 => 'No',
-            1 => 'Yes',
-            2 => 'Yes (mandatory)',
+            0 => Translatable('No'),
+            1 => Translatable('Yes'),
+            2 => Translatable('Yes (mandatory)'),
         };
 
         my $ProcessData = $Self->_GetProcessData(
@@ -519,10 +522,22 @@ sub Run {
             }
         }
 
-        my $SkinSelected = $Self->{'UserSkin'}
-            || $SkinSelectedHostBased
-            || $ConfigObject->Get('Loader::Agent::DefaultSelectedSkin')
-            || 'default';
+        my $SkinSelected = $Self->{'UserSkin'};
+
+        # check if the skin is valid
+        my $SkinValid = 0;
+        if ($SkinSelected) {
+            $SkinValid = $LayoutObject->SkinValidate(
+                SkinType => 'Agent',
+                Skin     => $SkinSelected,
+            );
+        }
+
+        if ( !$SkinValid ) {
+            $SkinSelected = $SkinSelectedHostBased
+                || $ConfigObject->Get('Loader::Agent::DefaultSelectedSkin')
+                || 'default';
+        }
 
         my %AgentLogo;
 
@@ -642,7 +657,7 @@ sub Run {
         );
         if ( !$ProcessData ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Unknown Process $ProcessID!",
+                Message => $LayoutObject->{LanguageObject}->Translate( 'Unknown Process %s!', $ProcessID ),
             );
         }
 
@@ -662,7 +677,7 @@ sub Run {
         # show error if can't generate a new EntityID
         if ( !$EntityID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error generating a new EntityID for this Process",
+                Message => Translatable('There was an error generating a new EntityID for this Process'),
             );
         }
 
@@ -675,7 +690,7 @@ sub Run {
         # show error if  StateEntityID for Inactive does not exist
         if ( !$EntityID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "The StateEntityID for for state Inactive does not exists",
+                Message => Translatable('The StateEntityID for state Inactive does not exists'),
             );
         }
 
@@ -692,7 +707,7 @@ sub Run {
         # show error if can't create
         if ( !$ProcessID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the Process",
+                Message => Translatable('There was an error creating the Process'),
             );
         }
 
@@ -707,8 +722,9 @@ sub Run {
         # show error if can't set
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error setting the entity sync status for Process "
-                    . "entity:$EntityID",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'There was an error setting the entity sync status for Process entity: %s', $EntityID
+                ),
             );
         }
 
@@ -752,14 +768,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{Description} ) {
 
             # add server error error class
             $Error{DescriptionServerError}        = 'ServerError';
-            $Error{DescriptionServerErrorMessage} = 'This field is required';
+            $Error{DescriptionServerErrorMessage} = Translatable('This field is required');
         }
 
         # check if state exists
@@ -791,7 +807,7 @@ sub Run {
         # show error if can't generate a new EntityID
         if ( !$EntityID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error generating a new EntityID for this Process",
+                Message => Translatable('There was an error generating a new EntityID for this Process'),
             );
         }
 
@@ -808,7 +824,7 @@ sub Run {
         # show error if can't create
         if ( !$ProcessID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the Process",
+                Message => Translatable('There was an error creating the Process'),
             );
         }
 
@@ -823,8 +839,9 @@ sub Run {
         # show error if can't set
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error setting the entity sync status for Process "
-                    . "entity:$EntityID",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'There was an error setting the entity sync status for Process entity: %s', $EntityID
+                ),
             );
         }
 
@@ -844,7 +861,7 @@ sub Run {
         # check for ProcessID
         if ( !$ProcessID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need ProcessID!",
+                Message => Translatable('Need ProcessID!'),
             );
         }
 
@@ -877,7 +894,8 @@ sub Run {
         # check for valid Process data
         if ( !IsHashRefWithData($ProcessData) ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Could not get data for ProcessID $ProcessID",
+                Message =>
+                    $LayoutObject->{LanguageObject}->Translate( 'Could not get data for ProcessID %s', $ProcessID ),
             );
         }
 
@@ -919,14 +937,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{Description} ) {
 
             # add server error error class
             $Error{DescriptionServerError}        = 'ServerError';
-            $Error{DescriptionServerErrorMessage} = 'This field is required';
+            $Error{DescriptionServerErrorMessage} = Translatable('This field is required');
         }
 
         # check if state exists
@@ -963,7 +981,7 @@ sub Run {
         # show error if can't update
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error updating the Process",
+                Message => Translatable('There was an error updating the Process'),
             );
         }
 
@@ -978,8 +996,10 @@ sub Run {
         # show error if can't set
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error setting the entity sync status for Process "
-                    . "entity:$ProcessData->{EntityID}",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'There was an error setting the entity sync status for Process entity: %s',
+                    $ProcessData->{EntityID}
+                ),
             );
         }
 
@@ -1050,7 +1070,8 @@ sub Run {
             );
 
             if ( !$Success ) {
-                $DeleteResult{Message} = 'Process:$ProcessID could not be deleted';
+                $DeleteResult{Message}
+                    = $LayoutObject->{LanguageObject}->Translate( 'Process: %s could not be deleted', $ProcessID );
             }
             else {
 
@@ -1065,8 +1086,10 @@ sub Run {
                 # show error if cant set
                 if ( !$Success ) {
                     $DeleteResult{Success} = $Success;
-                    $DeleteResult{Message} = "There was an error setting the entity sync status "
-                        . "for Process entity:$CheckResult->{ProcessData}->{EntityID}"
+                    $DeleteResult{Message} = $LayoutObject->{LanguageObject}->Translate(
+                        'There was an error setting the entity sync status for Process entity: %s',
+                        $CheckResult->{ProcessData}->{EntityID}
+                    );
                 }
             }
 
@@ -1122,7 +1145,7 @@ sub Run {
 
                 # show error if can't set state
                 return $LayoutObject->ErrorScreen(
-                    Message => "There was an error setting the entity sync status.",
+                    Message => Translatable('There was an error setting the entity sync status.'),
                 );
             }
         }
@@ -1130,7 +1153,7 @@ sub Run {
 
             # show error if can't synch
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error synchronizing the processes.",
+                Message => Translatable('There was an error synchronizing the processes.'),
             );
         }
     }
@@ -1197,7 +1220,8 @@ sub Run {
             $JSON = $LayoutObject->JSONEncode(
                 Data => {
                     Success => 0,
-                    Message => "The $GetParam{EntityType}:$GetParam{EntityID} is still in use",
+                    Message => $LayoutObject->{LanguageObject}
+                        ->Translate( 'The %s:%s is still in use', $GetParam{EntityType}, $GetParam{EntityID} ),
                 },
             );
         }
@@ -1214,8 +1238,10 @@ sub Run {
                 $JSON = $LayoutObject->JSONEncode(
                     Data => {
                         Success => 0,
-                        Message => "The $GetParam{EntityType}:$GetParam{ItemID} has a different"
-                            . " EntityID",
+                        Message => $LayoutObject->{LanguageObject}->Translate(
+                            'The %s:%s has a different EntityID',
+                            $GetParam{EntityType}, $GetParam{ItemID}
+                        ),
                     },
                 );
             }
@@ -1232,7 +1258,8 @@ sub Run {
                 my $Message;
                 if ( !$Success ) {
                     $Success = 0;
-                    $Message = "Could not delete $GetParam{EntityType}:$GetParam{ItemID}";
+                    $Message = $LayoutObject->{LanguageObject}
+                        ->Translate( 'Could not delete %s:%s', $GetParam{EntityType}, $GetParam{ItemID} );
                 }
                 else {
 
@@ -1247,8 +1274,10 @@ sub Run {
                     # show error if cant set
                     if ( !$Success ) {
                         $Success = 0;
-                        $Message = "There was an error setting the entity sync status for "
-                            . "$GetParam{EntityType} entity:$Entity->{EntityID}"
+                        $Message = $LayoutObject->{LanguageObject}->Translate(
+                            'There was an error setting the entity sync status for %s entity: %s',
+                            $GetParam{EntityType}, $Entity->{EntityID}
+                        );
                     }
                 }
 
@@ -1315,7 +1344,7 @@ sub Run {
             $JSON = $LayoutObject->JSONEncode(
                 Data => {
                     Success => 0,
-                    Message => "Could not get $GetParam{EntityType}",
+                    Message => $LayoutObject->{LanguageObject}->Translate( 'Could not get %s', $GetParam{EntityType} ),
                 },
             );
         }
@@ -1456,7 +1485,7 @@ sub Run {
             $Param{$Needed} = $ParamObject->GetParam( Param => $Needed ) || '';
             if ( !$Param{$Needed} ) {
                 $Success = 0;
-                $Message = 'Need $Needed!';
+                $Message = $LayoutObject->{LanguageObject}->Translate( 'Need %s!', $Needed );
             }
         }
 
@@ -1795,6 +1824,8 @@ sub _GetParams {
 sub _CheckProcessDelete {
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     # get Process data
     my $ProcessData = $Kernel::OM->Get('Kernel::System::ProcessManagement::DB::Process')->ProcessGet(
         ID     => $Param{ID},
@@ -1805,7 +1836,7 @@ sub _CheckProcessDelete {
     if ( !IsHashRefWithData($ProcessData) ) {
         return {
             Success => 0,
-            Message => "Could not get data for ProcessID $Param{ID}",
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Could not get data for ProcessID %s', $Param{ID} ),
         };
     }
 
@@ -1818,7 +1849,7 @@ sub _CheckProcessDelete {
     if ( $State ne 'Inactive' ) {
         return {
             Success => 0,
-            Message => "Process:$Param{ID} is not Inactive",
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Process: %s is not Inactive', $Param{ID} ),
         };
     }
 
@@ -1979,6 +2010,8 @@ sub _GetProcessData {
 
     my ( $Self, %Param ) = @_;
 
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     my %ProcessData;
 
     # get process data
@@ -1987,8 +2020,8 @@ sub _GetProcessData {
         UserID => $Self->{UserID},
     );
     if ( !$Process ) {
-        return $Kernel::OM->Get('Kernel::Output::HTML::Layout')->ErrorScreen(
-            Message => "Unknown Process $Param{ID}!",
+        return $LayoutObject->ErrorScreen(
+            Message => $LayoutObject->{LanguageObject}->Translate( 'Unknown Process %s!', $Param{ID} ),
         );
     }
     $ProcessData{Process} = $Process;
