@@ -11,6 +11,7 @@ package Kernel::Modules::AdminProcessManagementActivityDialog;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 our $ObjectManagerDisabled = 1;
@@ -178,14 +179,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{DescriptionShort} ) {
 
             # add server error error class
             $Error{DescriptionShortServerError} = 'ServerError';
-            $Error{DecriptionShortErrorMessage} = 'This field is required';
+            $Error{DecriptionShortErrorMessage} = Translatable('This field is required');
         }
 
         # check if permission exists
@@ -228,7 +229,7 @@ sub Run {
         # show error if can't generate a new EntityID
         if ( !$EntityID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error generating a new EntityID for this ActivityDialog",
+                Message => Translatable("There was an error generating a new EntityID for this ActivityDialog"),
             );
         }
 
@@ -243,7 +244,7 @@ sub Run {
         # show error if can't create
         if ( !$ActivityDialogID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error creating the ActivityDialog",
+                Message => Translatable("There was an error creating the ActivityDialog"),
             );
         }
 
@@ -258,8 +259,10 @@ sub Run {
         # show error if can't set
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error setting the entity sync status for ActivityDialog "
-                    . "entity:$EntityID",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'There was an error setting the entity sync status for ActivityDialog entity: %s',
+                    $EntityID
+                ),
             );
         }
 
@@ -331,7 +334,7 @@ sub Run {
         # check for ActivityDialogID
         if ( !$ActivityDialogID ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Need ActivityDialogID!",
+                Message => Translatable("Need ActivityDialogID!"),
             );
         }
 
@@ -347,7 +350,10 @@ sub Run {
         # check for valid Activity Dialog data
         if ( !IsHashRefWithData($ActivityDialogData) ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Could not get data for ActivityDialogID $ActivityDialogID",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'Could not get data for ActivityDialogID %s',
+                    $ActivityDialogID
+                ),
             );
         }
 
@@ -438,14 +444,14 @@ sub Run {
 
             # add server error error class
             $Error{NameServerError}        = 'ServerError';
-            $Error{NameServerErrorMessage} = 'This field is required';
+            $Error{NameServerErrorMessage} = Translatable('This field is required');
         }
 
         if ( !$GetParam->{DescriptionShort} ) {
 
             # add server error error class
             $Error{DescriptionShortServerError} = 'ServerError';
-            $Error{DecriptionShortErrorMessage} = 'This field is required';
+            $Error{DecriptionShortErrorMessage} = Translatable('This field is required');
         }
 
         # check if permission exists
@@ -492,7 +498,7 @@ sub Run {
         # show error if can't update
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error updating the ActivityDialog",
+                Message => Translatable("There was an error updating the ActivityDialog"),
             );
         }
 
@@ -507,8 +513,10 @@ sub Run {
         # show error if can't set
         if ( !$Success ) {
             return $LayoutObject->ErrorScreen(
-                Message => "There was an error setting the entity sync status for ActivityDialog "
-                    . "entity:$ActivityDialogData->{EntityID}",
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'There was an error setting the entity sync status for ActivityDialog entity: %s',
+                    $ActivityDialogData->{EntityID}
+                ),
             );
         }
 
@@ -588,7 +596,7 @@ sub Run {
     # ------------------------------------------------------------ #
     else {
         return $LayoutObject->ErrorScreen(
-            Message => "This subaction is not valid",
+            Message => Translatable("This subaction is not valid"),
         );
     }
 }
@@ -768,7 +776,10 @@ sub _ShowEdit {
             );
         }
 
-        $Param{Title} = "Edit Activity Dialog \"$ActivityDialogData->{Name}\"";
+        $Param{Title} = $LayoutObject->{LanguageObject}->Translate(
+            'Edit Activity Dialog "%s"',
+            $ActivityDialogData->{Name}
+        );
     }
     else {
 
@@ -794,7 +805,7 @@ sub _ShowEdit {
             );
         }
 
-        $Param{Title} = 'Create New Activity Dialog';
+        $Param{Title} = Translatable('Create New Activity Dialog');
     }
 
     # get interface infos
@@ -817,9 +828,9 @@ sub _ShowEdit {
     # create interface selection
     $Param{InterfaceSelection} = $LayoutObject->BuildSelection(
         Data => {
-            AgentInterface    => 'Agent Interface',
-            CustomerInterface => 'Customer Interface',
-            BothInterfaces    => 'Agent and Customer Interface',
+            AgentInterface    => Translatable('Agent Interface'),
+            CustomerInterface => Translatable('Customer Interface'),
+            BothInterfaces    => Translatable('Agent and Customer Interface'),
         },
         Name         => 'Interface',
         ID           => 'Interface',
@@ -845,8 +856,8 @@ sub _ShowEdit {
     # create "required lock" selection
     $Param{RequiredLockSelection} = $LayoutObject->BuildSelection(
         Data => {
-            0 => 'No',
-            1 => 'Yes',
+            0 => Translatable('No'),
+            1 => Translatable('Yes'),
         },
         Name        => 'RequiredLock',
         ID          => 'RequiredLock',
@@ -859,9 +870,9 @@ sub _ShowEdit {
     # create Display selection
     $Param{DisplaySelection} = $LayoutObject->BuildSelection(
         Data => {
-            0 => 'Do not show Field',
-            1 => 'Show Field',
-            2 => 'Show Field As Mandatory',
+            0 => Translatable('Do not show Field'),
+            1 => Translatable('Show Field'),
+            2 => Translatable('Show Field As Mandatory'),
         },
         Name        => 'Display',
         ID          => 'Display',
@@ -873,15 +884,15 @@ sub _ShowEdit {
     # create ArticleType selection
     $Param{ArticleTypeSelection} = $LayoutObject->BuildSelection(
         Data => [
-            'note-internal',
-            'note-external',
-            'note-report',
-            'phone',
-            'fax',
-            'sms',
-            'webrequest',
+            Translatable('note-internal'),
+            Translatable('note-external'),
+            Translatable('note-report'),
+            Translatable('phone'),
+            Translatable('fax'),
+            Translatable('sms'),
+            Translatable('webrequest'),
         ],
-        SelectedValue => 'note-internal',
+        SelectedValue => Translatable('note-internal'),
         Name          => 'ArticleType',
         ID            => 'ArticleType',
         Sort          => 'Alphanumeric',
@@ -890,8 +901,8 @@ sub _ShowEdit {
     );
 
     my %TimeUnitsSelectionList = (
-        0 => 'Do not show Field',
-        2 => 'Show Field As Mandatory',
+        0 => Translatable('Do not show Field'),
+        2 => Translatable('Show Field As Mandatory'),
     );
 
     if ( !$ConfigObject->Get('Ticket::Frontend::NeedAccountedTime') ) {
