@@ -11,6 +11,8 @@ package Kernel::Modules::AgentLinkObject;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our $ObjectManagerDisabled = 1;
 
 sub new {
@@ -28,6 +30,64 @@ sub Run {
 
     my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
+    if ( $Self->{Subaction} eq 'UpdateComplextTablePreferences' ) {
+
+        # save user preferences (shown columns)
+
+        # Needed objects
+        my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
+        my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+        my $JSONObject   = $Kernel::OM->Get('Kernel::System::JSON');
+
+        # challenge token check for write action
+        $LayoutObject->ChallengeTokenCheck();
+
+        my $SourceObject      = $ParamObject->GetParam( Param => 'SourceObject' )      || '';
+        my $DestinationObject = $ParamObject->GetParam( Param => 'DestinationObject' ) || '';
+
+        my $Success = $LayoutObject->ComplexTablePreferencesSet(
+            DestinationObject => $DestinationObject,
+        );
+
+        if ( !$Success ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "System was unable to update preferences!",
+            );
+            return;
+        }
+
+        # get linked objects
+        my $LinkListWithData = $Kernel::OM->Get('Kernel::System::LinkObject')->LinkListWithData(
+            Object           => $SourceObject,
+            Object2          => $DestinationObject,
+            Key              => $Self->{TicketID},
+            State            => 'Valid',
+            UserID           => $Self->{UserID},
+            ObjectParameters => {
+                Ticket => {
+                    IgnoreLinkedTicketStateTypes => 1,
+                },
+            },
+        );
+
+        # create the link table
+        my $LinkTableStrg = $LayoutObject->LinkObjectTableCreate(
+            LinkListWithData => $LinkListWithData,
+            ViewMode         => 'Complex',           # only make sense for complex
+            Object           => $SourceObject,
+            Key              => $Self->{TicketID},
+            AJAX             => 1,
+        );
+
+        return $LayoutObject->Attachment(
+            ContentType => 'text/html',
+            Content     => $LinkTableStrg,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+
     # ------------------------------------------------------------ #
     # close
     # ------------------------------------------------------------ #
@@ -47,8 +107,8 @@ sub Run {
     # check needed stuff
     if ( !$Form{SourceObject} || !$Form{SourceKey} ) {
         return $LayoutObject->ErrorScreen(
-            Message => "Need SourceObject and SourceKey!",
-            Comment => 'Please contact the admin.',
+            Message => Translatable('Need SourceObject and SourceKey!'),
+            Comment => Translatable('Please contact the admin.'),
         );
     }
 
@@ -77,7 +137,7 @@ sub Run {
 
         if ( !$Permission ) {
             return $LayoutObject->NoPermission(
-                Message    => 'You need ro permission!',
+                Message    => Translatable('You need ro permission!'),
                 WithHeader => 'yes',
             );
         }
@@ -354,13 +414,10 @@ sub Run {
                         $Output .= $LayoutObject->Notify(
                             Priority => 'Error',
                             Data     => $LayoutObject->{LanguageObject}->Translate(
-                                "Can not create link with %s!",
+                                'Can not create link with %s! Object already linked as %s.',
                                 $TargetObjectDescription{Normal},
-                                )
-                                . $LayoutObject->{LanguageObject}->Translate(
-                                "Object already linked as %s.",
                                 $TypeName,
-                                ),
+                            ),
                         );
 
                         next TARGETKEYORG;
@@ -443,8 +500,9 @@ sub Run {
         # check needed stuff
         if ( !$TargetObjectStrg ) {
             return $LayoutObject->ErrorScreen(
-                Message => "The Object $Form{SourceObject} cannot link with other object!",
-                Comment => 'Please contact the admin.',
+                Message => $LayoutObject->{LanguageObject}
+                    ->Translate( 'The object %s cannot link with other object!', $Form{SourceObject} ),
+                Comment => Translatable('Please contact the admin.'),
             );
         }
 
