@@ -13,6 +13,8 @@ use warnings;
 
 our $ObjectManagerDisabled = 1;
 
+use Kernel::Language qw(Translatable);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -33,13 +35,14 @@ sub Run {
 
     if ( !$AccessControlRexExp ) {
         return $LayoutObject->ErrorScreen(
-            Message => 'Need config Package::RepositoryAccessRegExp',
+            Message => Translatable('Need config Package::RepositoryAccessRegExp'),
         );
     }
     else {
         if ( $ENV{REMOTE_ADDR} !~ /^$AccessControlRexExp$/ ) {
             return $LayoutObject->ErrorScreen(
-                Message => "Authentication failed from $ENV{REMOTE_ADDR}!",
+                Message =>
+                    $LayoutObject->{LanguageObject}->Translate( 'Authentication failed from %s!', $ENV{REMOTE_ADDR} ),
             );
         }
     }
