@@ -11,6 +11,8 @@ package Kernel::Output::HTML::QueuePreferences::Generic;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::Web::Request',
     'Kernel::System::Queue',
@@ -64,7 +66,7 @@ sub Run {
             );
         }
     }
-    $Self->{Message} = 'Preferences updated successfully!';
+    $Self->{Message} = Translatable('Preferences updated successfully!');
     return 1;
 }
 
