@@ -558,7 +558,7 @@ sub MigrateDTLtoTT {
         }esmxg;
 
     # drop empty $Text
-    $Content =~ s{\$Text{""}}{}xmsg;
+    $Content =~ s{ \$Text [{] "" [}] }{}xmsg;
 
     # $JSText
     $Content =~ s{
