@@ -11,6 +11,8 @@ package Kernel::System::Auth;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::Group',
@@ -158,35 +160,10 @@ sub Auth {
         # next on no success
         next COUNT if !$User;
 
-        my $UserID = $UserObject->UserLookup(
-            UserLogin => $User,
-        );
-
-        # check 2factor auth backends
-        my $TwoFactorAuth;
-        TWOFACTORSOURCE:
-        for my $Count ( '', 1 .. 10 ) {
-
-            # return on no config setting
-            next TWOFACTORSOURCE if !$Self->{"AuthTwoFactorBackend$Count"};
-
-            # 2factor backend
-            my $AuthOk = $Self->{"AuthTwoFactorBackend$Count"}->Auth(
-                TwoFactorToken => $Param{TwoFactorToken},
-                User           => $User,
-                UserID         => $UserID,
-            );
-            $TwoFactorAuth = $AuthOk ? 'passed' : 'failed';
-
-            last TWOFACTORSOURCE if $AuthOk;
-        }
-
-        # if at least one 2factor auth backend was checked but none was successful,
-        # it counts as a failed login
-        if ( $TwoFactorAuth && $TwoFactorAuth ne 'passed' ) {
-            $User = undef;
-            last COUNT;
-        }
+        # Sync will happen before two factor authentication (if configured)
+        # because user might not exist before being created in sync (see bug #11966).
+        # A failed two factor auth after successful sync will result
+        # in a new or updated user but no information or permission leak.
 
         # configured auth sync backend
         my $AuthSyncBackend = $ConfigObject->Get("AuthModule::UseSyncBackend$Count");
@@ -220,15 +197,50 @@ sub Auth {
             }
         }
 
-        # remember auth backend
-        if ($UserID) {
-            $UserObject->SetPreferences(
-                Key    => 'UserAuthBackend',
-                Value  => $Count,
-                UserID => $UserID,
+        # If we have no UserID at this point
+        # it means auth was ok but user didn't exist before
+        # and wasn't created in sync module.
+        # We will skip two factor authentication even if configured
+        # because we don't have user data to compare the otp anyway.
+        # This will not count as a failed login.
+        my $UserID = $UserObject->UserLookup(
+            UserLogin => $User,
+        );
+        last COUNT if !$UserID;
+
+        # check 2factor auth backends
+        my $TwoFactorAuth;
+        TWOFACTORSOURCE:
+        for my $Count ( '', 1 .. 10 ) {
+
+            # return on no config setting
+            next TWOFACTORSOURCE if !$Self->{"AuthTwoFactorBackend$Count"};
+
+            # 2factor backend
+            my $AuthOk = $Self->{"AuthTwoFactorBackend$Count"}->Auth(
+                TwoFactorToken => $Param{TwoFactorToken},
+                User           => $User,
+                UserID         => $UserID,
             );
+            $TwoFactorAuth = $AuthOk ? 'passed' : 'failed';
+
+            last TWOFACTORSOURCE if $AuthOk;
         }
 
+        # if at least one 2factor auth backend was checked but none was successful,
+        # it counts as a failed login
+        if ( $TwoFactorAuth && $TwoFactorAuth ne 'passed' ) {
+            $User = undef;
+            last COUNT;
+        }
+
+        # remember auth backend
+        $UserObject->SetPreferences(
+            Key    => 'UserAuthBackend',
+            Value  => $Count,
+            UserID => $UserID,
+        );
+
         last COUNT;
     }
 
@@ -326,7 +338,7 @@ sub Auth {
 
             $Self->{LastErrorMessage} =
                 $ConfigObject->Get('SystemMaintenance::IsActiveDefaultLoginErrorMessage')
-                || "It is currently not possible to login due to a scheduled system maintenance.";
+                || Translatable("It is currently not possible to login due to a scheduled system maintenance.");
 
             return;
         }
