@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,12 @@ package Kernel::System::AuthSession;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+);
+
 =head1 NAME
 
 Kernel::System::AuthSession - global session interface
@@ -27,47 +33,11 @@ All session functions.
 
 =item new()
 
-create an object
+create an object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::Time;
-    use Kernel::System::DB;
-    use Kernel::System::AuthSession;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $SessionObject = Kernel::System::AuthSession->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-        TimeObject   => $TimeObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $SessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
 
 =cut
 
@@ -78,21 +48,19 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for (qw(LogObject ConfigObject TimeObject DBObject MainObject EncodeObject)) {
-        $Self->{$_} = $Param{$_} || die "No $_!";
-    }
-
     # get configured session backend
-    my $GenericModule = $Self->{ConfigObject}->Get('SessionModule');
+    my $GenericModule = $Kernel::OM->Get('Kernel::Config')->Get('SessionModule');
     $GenericModule ||= 'Kernel::System::AuthSession::DB';
 
+    # get main object
+    my $MainObject = $Kernel::OM->Get('Kernel::System::Main');
+
     # load session backend module
-    if ( !$Self->{MainObject}->Require($GenericModule) ) {
-        $Self->{MainObject}->Die("Can't load backend module $GenericModule! $@");
+    if ( !$MainObject->Require($GenericModule) ) {
+        $MainObject->Die("Can't load backend module $GenericModule! $@");
     }
 
-    $Self->{Backend} = $GenericModule->new( %{$Self} );
+    $Self->{Backend} = $GenericModule->new();
 
     return $Self;
 }
@@ -207,7 +175,7 @@ sub UpdateSessionID {
         my @Parts = split /:/, $Param{Key};
 
         if ( defined $Parts[1] ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Can't update key: '$Param{Key}' because ':' is not allowed!",
             );
@@ -220,7 +188,8 @@ sub UpdateSessionID {
 
 =item GetExpiredSessionIDs()
 
-returns a array with expired session ids
+returns a array of an array of session ids that have expired,
+and one array of session ids that have been idle for too long.
 
     my @Sessions = $SessionObject->GetExpiredSessionIDs();
 
@@ -237,7 +206,7 @@ sub GetExpiredSessionIDs {
 
 =item GetAllSessionIDs()
 
-returns a array with all session ids
+returns an array with all session ids
 
     my @Sessions = $SessionObject->GetAllSessionIDs();
 
