@@ -18,6 +18,7 @@ use base qw(Kernel::System::Console::BaseCommand);
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::CustomerUser',
+    'Kernel::System::CustomerCompany',
     'Kernel::System::DB',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
@@ -59,6 +60,13 @@ sub Configure {
         HasValue    => 1,
         ValueRegex  => qr/^\d+$/smx,
     );
+    $Self->AddOption(
+        Name        => 'generate-customer-companies',
+        Description => "Specify how many customer companies should be generated.",
+        Required    => 0,
+        HasValue    => 1,
+        ValueRegex  => qr/^\d+$/smx,
+    );
     $Self->AddOption(
         Name        => 'generate-groups',
         Description => "Specify how many groups should be generated.",
@@ -139,10 +147,16 @@ sub Run {
         @QueueIDs = QueueCreate( $Self->GetOption('generate-queues'), \@GroupIDs );
     }
 
+    # customer users
     if ( $Self->GetOption('generate-customer-users') ) {
         CustomerCreate( $Self->GetOption('generate-customer-users') );
     }
 
+    # customer companies
+    if ( $Self->GetOption('generate-customer-companies') ) {
+        CompanyCreate( $Self->GetOption('generate-customer-companies') );
+    }
+
     my $Counter = 1;
 
     # create tickets
@@ -535,6 +549,30 @@ sub CustomerCreate {
     }
 }
 
+sub CompanyCreate {
+    my $Count = shift || return;
+
+    for ( 1 .. $Count ) {
+
+        my $Name       = 'fill-up-company' . int( rand(100_000_000) );
+        my $CustomerID = $Kernel::OM->Get('Kernel::System::CustomerCompany')->CustomerCompanyAdd(
+            Source                 => 'CustomerCompany',          # CustomerCompany source config
+            CustomerID             => $Name . '_CustomerID',
+            CustomerCompanyName    => $Name,
+            CustomerCompanyStreet  => '5201 Blue Lagoon Drive',
+            CustomerCompanyZIP     => '33126',
+            CustomerCompanyCity    => 'Miami',
+            CustomerCompanyCountry => 'USA',
+            CustomerCompanyURL     => 'http://www.example.org',
+            CustomerCompanyComment => 'some comment',
+            ValidID                => 1,
+            UserID                 => 1,
+        );
+
+        print "CustomerCompany '$Name' created.\n";
+    }
+}
+
 1;
 
 =back
