@@ -11,6 +11,8 @@ package Kernel::System::CustomerAuth;
 use strict;
 use warnings;
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
     'Kernel::System::CustomerUser',
@@ -214,7 +216,7 @@ sub Auth {
 
         $Self->{LastErrorMessage} =
             $ConfigObject->Get('SystemMaintenance::IsActiveDefaultLoginErrorMessage')
-            || "It is currently not possible to login due to a scheduled system maintenance.";
+            || Translatable("It is currently not possible to login due to a scheduled system maintenance.");
 
         return;
     }
