@@ -352,8 +352,13 @@ sub EditFieldValueGet {
     my %Data;
 
     # check if there is a Template and retrieve the dynamic field value from there
-    if ( IsHashRefWithData( $Param{Template} ) && defined $Param{Template}->{$FieldName} ) {
-
+    if (
+        IsHashRefWithData( $Param{Template} ) && (
+            defined $Param{Template}->{$FieldName}
+            || defined $Param{Template}->{ $FieldName . 'Used' }
+        )
+        )
+    {
         # get dynamic field value form Template
         $Data{FieldValue} = $Param{Template}->{$FieldName};
 
