@@ -15,6 +15,7 @@ use warnings;
 use Mail::Address;
 use MIME::Entity;
 use MIME::Parser;
+use MIME::Words;
 
 use Kernel::System::VariableCheck qw(:all);
 
@@ -279,9 +280,15 @@ sub Send {
     my $Product = $ConfigObject->Get('Product');
     my $Version = $ConfigObject->Get('Version');
 
-    if ( !$ConfigObject->Get('Secure::DisableBanner') ) {
+    if ( $ConfigObject->Get('Secure::DisableBanner') ) {
+
+        # Set this to undef to avoid having a value like "MIME-tools 5.507 (Entity 5.507)"
+        #   which could lead to the mail being treated as SPAM.
+        $Header{'X-Mailer'} = undef;
+    }
+    else {
         $Header{'X-Mailer'}     = "$Product Mail Service ($Version)";
-        $Header{'X-Powered-By'} = 'OTRS - Open Ticket Request System (http://otrs.org/)';
+        $Header{'X-Powered-By'} = 'OTRS (https://otrs.com/)';
     }
     $Header{Type} = $Param{MimeType} || 'text/plain';
 
@@ -335,11 +342,7 @@ sub Send {
     KEY:
     for my $Key ( 'In-Reply-To', 'References' ) {
         next KEY if !$Param{$Key};
-        my $Value = $Param{$Key};
-
-        # Split up '<msgid><msgid>' to allow line folding (see bug#9345).
-        $Value =~ s{><}{> <}xmsg;
-        $Header->replace( $Key, $Value );
+        $Header->replace( $Key, $Param{$Key} );
     }
 
     # add attachments to email
@@ -697,6 +700,13 @@ sub Send {
     $Param{Header} = '';
     for my $Line (@Headers) {
         $Line =~ s/^    (.*)$/ $1/;
+
+        # Perform own wrapping of long lines due to MIME::Tools problems (see bug#9345).
+        #  MIME::Tools fails to wrap long lines where the Message-IDs are too long or
+        #  directly concatenated without spaces in between.
+        if ( $Line =~ m{^(References|In-Reply-To):}smx ) {
+            $Line =~ s{(.{64,}?)>\s*<}{$1>\n <}sxmg;
+        }
         $Param{Header} .= $Line . "\n";
     }
 
@@ -816,13 +826,7 @@ sub Bounce {
     }
 
     # check and create message id
-    my $MessageID = '';
-    if ( $Param{'Message-ID'} ) {
-        $MessageID = $Param{'Message-ID'};
-    }
-    else {
-        $MessageID = $Self->_MessageIDCreate();
-    }
+    my $MessageID = $Param{'Message-ID'} || $Self->_MessageIDCreate();
 
     # split body && header
     my @EmailPlain = split( /\n/, $Param{Email} );
@@ -832,13 +836,12 @@ sub Bounce {
     my @Sender   = Mail::Address->parse( $Param{From} );
     my $RealFrom = $Sender[0]->address();
 
-    # add ReSent header
+    # add ReSent header (see https://www.ietf.org/rfc/rfc2822.txt A.3. Resent messages)
     my $HeaderObject = $EmailObject->head();
-    my $OldMessageID = $HeaderObject->get('Message-ID') || '??';
-    $HeaderObject->replace( 'Message-ID',        $MessageID );
-    $HeaderObject->replace( 'ReSent-Message-ID', $OldMessageID );
+    $HeaderObject->replace( 'Resent-Message-ID', $MessageID );
     $HeaderObject->replace( 'Resent-To',         $Param{To} );
     $HeaderObject->replace( 'Resent-From',       $RealFrom );
+    $HeaderObject->replace( 'Resent-Date',       $Kernel::OM->Get('Kernel::System::Time')->MailTimeStamp() );
     my $Body         = $EmailObject->body();
     my $BodyAsString = '';
     for ( @{$Body} ) {
@@ -848,6 +851,7 @@ sub Bounce {
 
     # debug
     if ( $Self->{Debug} > 1 ) {
+        my $OldMessageID = $HeaderObject->get('Message-ID') || '??';
         $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'notice',
             Message  => "Bounced email to '$Param{To}' from '$RealFrom'. "
@@ -877,39 +881,17 @@ sub _EncodeMIMEWords {
     # return if no content is given
     return '' if !defined $Param{Line};
 
-    # check if MIME::EncWords is installed
-    if ( eval { require MIME::EncWords } ) {    ## no critic
-        return MIME::EncWords::encode_mimewords(
-            Encode::encode(
-                $Param{Charset},
-                $Param{Line},
-            ),
-            Charset => $Param{Charset},
+    return MIME::Words::encode_mimewords(
+        Encode::encode(
+            $Param{Charset},
+            $Param{Line},
+        ),
+        Charset => $Param{Charset},
 
-            # use 'a' for quoted printable or base64 choice automatically
-            Encoding => 'a',
-
-            # for line length calculation to fold lines
-            Field => $Param{Field},
-        );
-    }
-
-    # as fallback use MIME::Words of MIME::Tools (but it lakes on some utf8
-    # issues, see pod of MIME::Words)
-    else {
-        require MIME::Words;    ## no critic
-        return MIME::Words::encode_mimewords(
-            Encode::encode(
-                $Param{Charset},
-                $Param{Line},
-            ),
-            Charset => $Param{Charset},
-
-            # for line length calculation to fold lines (gets ignored by
-            # MIME::Words, see pod of MIME::Words)
-            Field => $Param{Field},
-        );
-    }
+        # for line length calculation to fold lines (gets ignored by
+        # MIME::Words, see pod of MIME::Words)
+        Field => $Param{Field},
+    );
 }
 
 sub _MessageIDCreate {
@@ -917,7 +899,7 @@ sub _MessageIDCreate {
 
     my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
 
-    return 'Message-ID: <' . time() . '.' . rand(999999) . '@' . $FQDN . '>';
+    return '<' . time() . '.' . rand(999999) . '@' . $FQDN . '>';
 }
 
 1;
