@@ -110,16 +110,25 @@ sub GroupAdd {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(Name ValidID UserID)) {
-        if ( !$Param{$_} ) {
+    for my $Needed (qw(Name ValidID UserID)) {
+        if ( !$Param{$Needed} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!",
+                Message  => "Need $Needed!",
             );
             return;
         }
     }
 
+    my %ExistingGroups = reverse $Self->GroupList( Valid => 0 );
+    if ( defined $ExistingGroups{ $Param{Name} } ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A Group with the name $Param{Name} already exists.",
+        );
+        return;
+    }
+
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
@@ -232,16 +241,25 @@ sub GroupUpdate {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(ID Name ValidID UserID)) {
-        if ( !$Param{$_} ) {
+    for my $Needed (qw(ID Name ValidID UserID)) {
+        if ( !$Param{$Needed} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!",
+                Message  => "Need $Needed!",
             );
             return;
         }
     }
 
+    my %ExistingGroups = reverse $Self->GroupList( Valid => 0 );
+    if ( defined $ExistingGroups{ $Param{Name} } && $ExistingGroups{ $Param{Name} } != $Param{ID} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A Group with the name $Param{Name} already exists.",
+        );
+        return;
+    }
+
     # set default value
     $Param{Comment} ||= '';
 
@@ -581,16 +599,25 @@ sub RoleAdd {
     my ( $Self, %Param ) = @_;
 
     # check needed stuff
-    for (qw(Name ValidID UserID)) {
-        if ( !$Param{$_} ) {
+    for my $Needed (qw(Name ValidID UserID)) {
+        if ( !$Param{$Needed} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $Needed!"
             );
             return;
         }
     }
 
+    my %ExistingRoles = reverse $Self->RoleList( Valid => 0 );
+    if ( defined $ExistingRoles{ $Param{Name} } ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A Role with the name $Param{Name} already exists.",
+        );
+        return;
+    }
+
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
@@ -664,6 +691,15 @@ sub RoleUpdate {
         }
     }
 
+    my %ExistingRoles = reverse $Self->RoleList( Valid => 0 );
+    if ( defined $ExistingRoles{ $Param{Name} } && $ExistingRoles{ $Param{Name} } != $Param{ID} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A Role with the name $Param{Name} already exists.",
+        );
+        return;
+    }
+
     # set default value
     $Param{Comment} ||= '';
 
@@ -988,20 +1024,20 @@ sub PermissionUserGet {
         UserID => $Param{UserID},
     );
 
-    return %GroupList if !%RoleList;
+    if (%RoleList) {
+        ROLEID:
+        for my $RoleID ( sort keys %RoleList ) {
 
-    ROLEID:
-    for my $RoleID ( sort keys %RoleList ) {
+            next ROLEID if !$RoleID;
 
-        next ROLEID if !$RoleID;
+            # get groups of the role
+            my %RoleGroupList = $Self->PermissionRoleGroupGet(
+                RoleID => $RoleID,
+                Type   => $Param{Type},
+            );
 
-        # get groups of the role
-        my %RoleGroupList = $Self->PermissionRoleGroupGet(
-            RoleID => $RoleID,
-            Type   => $Param{Type},
-        );
-
-        %GroupList = ( %GroupList, %RoleGroupList );
+            %GroupList = ( %GroupList, %RoleGroupList );
+        }
     }
 
     # set cache
@@ -1347,13 +1383,12 @@ sub PermissionUserGroupGet {
 
     return if !%PermissionTypeList;
 
-    # get valid user list
-    my %UserList = $Kernel::OM->Get('Kernel::System::User')->UserList(
-        Type => 'Short',
+    # check if user is valid
+    return if !$Kernel::OM->Get('Kernel::System::User')->GetUserData(
+        UserID => $Param{UserID},
+        Valid  => 1,
     );
 
-    return if !$UserList{ $Param{UserID} };
-
     # get group user data
     my %Permissions = $Self->_DBGroupUserGet(
         Type => 'UserPermGroup',
