@@ -188,13 +188,10 @@ sub Fetch {
             else {
 
                 # safety protection
-                $FetchCounter++;
-                if ( $FetchCounter > 10 ) {
-                    if ($CMD) {
-                        print
-                            "$AuthType: Safety protection: waiting 2 second before processing next mail...\n";
-                    }
-                    sleep 2;
+                my $FetchDelay = ( $FetchCounter % 20 == 0 ? 1 : 0 );
+                if ( $FetchDelay && $CMD ) {
+                    print "$AuthType: Safety protection: waiting 1 second before processing next mail...\n";
+                    sleep 1;
                 }
 
                 # get message (header and body)
