@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +11,10 @@ package Kernel::System::PostMaster::Filter::Match;
 use strict;
 use warnings;
 
+our @ObjectDependencies = (
+    'Kernel::System::Log',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -18,12 +22,10 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    $Self->{Debug} = $Param{Debug} || 0;
+    # get parser object
+    $Self->{ParserObject} = $Param{ParserObject} || die "Got no ParserObject!";
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject ParserObject)) {
-        $Self->{$_} = $Param{$_} || die "Got no $_!";
-    }
+    $Self->{Debug} = $Param{Debug} || 0;
 
     return $Self;
 }
@@ -34,7 +36,7 @@ sub Run {
     # check needed stuff
     for (qw(JobConfig GetParam)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -76,6 +78,7 @@ sub Run {
                 Line => $Param{GetParam}->{$_},
             );
             my $LocalMatched;
+            RECIPIENTS:
             for my $Recipients (@EmailAddresses) {
                 my $Email = $Self->{ParserObject}->GetEmailAddress( Email => $Recipients );
                 if ( $Email =~ /^$SearchEmail$/i ) {
@@ -84,12 +87,12 @@ sub Run {
                         $MatchedResult = $SearchEmail;
                     }
                     if ( $Self->{Debug} > 1 ) {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'debug',
                             Message  => "$Prefix'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched!",
                         );
                     }
-                    last;
+                    last RECIPIENTS;
                 }
             }
             if ( !$LocalMatched ) {
@@ -110,7 +113,7 @@ sub Run {
                 $MatchedResult = $1;
             }
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "$Prefix'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched!",
                 );
@@ -119,7 +122,7 @@ sub Run {
         else {
             $MatchedNot = 1;
             if ( $Self->{Debug} > 1 ) {
-                $Self->{LogObject}->Log(
+                $Kernel::OM->Get('Kernel::System::Log')->Log(
                     Priority => 'debug',
                     Message  => "$Prefix'$Param{GetParam}->{$_}' =~ /$Match{$_}/i matched NOT!",
                 );
@@ -132,7 +135,7 @@ sub Run {
         for ( sort keys %Set ) {
             $Set{$_} =~ s/\[\*\*\*\]/$MatchedResult/;
             $Param{GetParam}->{$_} = $Set{$_};
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message  => $Prefix
                     . "Set param '$_' to '$Set{$_}' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
@@ -141,7 +144,7 @@ sub Run {
 
         # stop after match
         if ($StopAfterMatch) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'notice',
                 Message  => $Prefix
                     . "Stopped filter processing because of used 'StopAfterMatch' (Message-ID: $Param{GetParam}->{'Message-ID'}) ",
