@@ -65,6 +65,7 @@ collect system data
     my %Result = $SupportDataCollectorObject->Collect(
         UseCache   => 1,    # (optional) to get data from cache if any
         WebTimeout => 60,   # (optional)
+        Hostname   => 'my.test.host:8080' # (optional, for testing purposes)
     );
 
     returns in case of error
@@ -117,7 +118,7 @@ sub Collect {
     # Data must be collected in a web request context to be able to collect web server data.
     #   If called from CLI, make a web request to collect the data.
     if ( !$ENV{GATEWAY_INTERFACE} ) {
-        return $Self->CollectByWebRequest( WebTimeout => $Param{WebTimeout} );
+        return $Self->CollectByWebRequest(%Param);
     }
 
     # Look for all plug-ins in the FS
@@ -214,19 +215,23 @@ sub CollectByWebRequest {
         );
     }
 
-    my $Host;
-    my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
+    my $Host = $Param{Hostname};
 
-    if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
-        $Host = $FQDN;
+    # Determine hostname
+    if ( !$Host ) {
+        my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
+
+        if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
+            $Host = $FQDN;
+        }
+
+        if ( !$Host && gethostbyname('localhost') ) {
+            $Host = 'localhost';
+        }
+
+        $Host ||= '127.0.0.1';
     }
 
-    if ( !$Host && gethostbyname('localhost') ) {
-        $Host = 'localhost';
-    }
-
-    $Host ||= '127.0.0.1';
-
     # if the public interface is proteceted with .htaccess
     # we can specify the htaccess login data here,
     # this is neccessary for the support data collector
