@@ -65,6 +65,16 @@ Core.Form.ErrorTooltips = (function (TargetNS) {
      *      Class name of the tooltip for the tongue position. Defines if the tongue is top or bottom.
      */
         TonguePosition = 'TongueBottom',
+
+    /**
+     * @private
+     * @name TongueHeight
+     * @memberof Core.Form.ErrorTooltips
+     * @member {Number}
+     * @description
+     *      Height of the tongue (css-based) which will be considered when the tooltip position is being calculated
+     */
+        TongueHeight = 10,
     /**
      * @private
      * @name $TooltipContent
@@ -133,19 +143,21 @@ Core.Form.ErrorTooltips = (function (TargetNS) {
 
         Offset = $Element.offset();
 
+        $TooltipContainer
+            .empty()
+            .append($Tooltip)
+            .show();
+
         if (TooltipPosition === 'TongueBottom') {
             TopOffset = Offset.top + TooltipOffsetTop;
         }
         else if (TooltipPosition === 'TongueTop') {
-            TopOffset = Offset.top - $Element.height() - TooltipOffsetTop;
+            TopOffset = Offset.top + $Element.height() - $TooltipContainer.height() - TooltipOffsetTop + TongueHeight;
         }
 
         $TooltipContainer
-            .empty()
-            .append($Tooltip)
             .css('left', Offset.left + TooltipOffsetLeft)
-            .css('top', TopOffset)
-            .show();
+            .css('top', TopOffset);
     };
 
     /**
